pygeodesy.albers._AlbersBase

Package pygeodesy :: Module albers :: Class _AlbersBase |
[frames] | no frames]

# Class _AlbersBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      _AlbersBase

Known Subclasses:
  - AlbersEqualArea
  - , AlbersEqualArea2
  - , AlbersEqualArea4
  - , AlbersEqualAreaCylindrical
  - , AlbersEqualAreaNorth
  - , AlbersEqualAreaSouth

(INTERNAL) Base class for `AlbersEqualArea...` projections.

See Also: Karney's C++ class AlbersEqualArea, method `Init`.

Instance Methods
__init__(self, sa1, ca1, sa2, ca2, k, datum, **name) (INTERNAL) New `AlbersEqualArea...` instance. |
forward(self, lat, lon, lon0=0, **name) Convert a geodetic location to east- and northing. |
rescale0(self, lat, k=1) Set the azimuthal scale for this projection. |
reverse(self, x, y, lon0=0, LatLon=None, **name_LatLon_kwds) Convert an east- and northing location to geodetic lat- and longitude. |
toRepr(self, prec=6, **unused) Return a string representation of this projection. |
toStr(self, prec=6, sep=' ', **unused) Return a string representation of this projection. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| datum Get the datum (Datum).
| ellipsoid Get the datum's ellipsoid (Ellipsoid).
| equatoradius Get the `ellipsoid`'s equatorial radius, semi-axis (`meter`).
| a Get the `ellipsoid`'s equatorial radius, semi-axis (`meter`).
| flattening Get the `ellipsoid`'s flattening (`scalar`).
| f Get the `ellipsoid`'s flattening (`scalar`).
| ispolar Is this projection polar (`bool`)?
| isPolar Is this projection polar (`bool`)?
| lat0 Get the latitude of the projection origin (`degrees`).
| lat1 Get the latitude of the first parallel (`degrees`).
| lat2 Get the latitude of the second parallel (`degrees`).
| majoradius DEPRECATED, use property `equatoradius`.
| scale0 Get the central scale for the projection (`float`).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, sa1, ca1, sa2, ca2, k, datum, **name) (Constructor) |
(INTERNAL) New `AlbersEqualArea...` instance. Overrides: object.__init__

### forward (self, lat, lon, lon0=0, **name) |
Convert a geodetic location to east- and northing. Arguments: `lat` - Latitude of the location (`degrees`). `lon` - Longitude of the location (`degrees`). `lon0` - Optional central meridian longitude (`degrees`). `name` - Optional `name=NN` for the location (`str`). Returns: An Albers7Tuple`(x, y, lat, lon, gamma, scale, datum)`, with `lon` offset by `lon0` and reduced `[-180,180]`. Note: The origin latitude is returned by `property lat0`. No false easting or northing is added. The value of `lat` should be in the range `[-90..90] degrees`. The returned values `x` and `y` will be large but finite for points projecting to infinity, i.e. one or both of the poles.

### rescale0 (self, lat, k=1) |
Set the azimuthal scale for this projection. Arguments: `lat` - Northern latitude (`degrees`). `k` - Azimuthal scale at latitude `lat` (`scalar`). Raises: `AlbersError` - Invalid `lat` or `k`. Note: This allows a latitude of conformality to be specified.

### reverse (self, x, y, lon0=0, LatLon=None, **name_LatLon_kwds) |
Convert an east- and northing location to geodetic lat- and longitude. Arguments: `x` - Easting of the location (`meter`). `y` - Northing of the location (`meter`). `lon0` - Optional central meridian longitude (`degrees`). `LatLon` - Class to use (`LatLon`) or `None`. `name_LatLon_kwds` - Optional `name=NN` for the location and optional, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: The geodetic (`LatLon`) or if `LatLon is None` an Albers7Tuple`(x, y, lat, lon, gamma, scale, datum)`. Note: The origin latitude is returned by `property lat0`. No false easting or northing is added. The returned value of `lon` is in the range `[-180..180] degrees` and `lat` is in the range `[-90..90] degrees`. If the given `x` or `y` point is outside the valid projected space the nearest pole is returned.

### toRepr (self, prec=6, **unused) |
Return a string representation of this projection. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). Returns: This projection as `"<classname>(lat1, lat2, ...)"` (`str`). Overrides: named._Named.toRepr

### toStr (self, prec=6, sep=' ', **unused) |
Return a string representation of this projection. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `sep` - Separator to join (`str`). Returns: This projection as `"lat1 lat2"` (`str`). Overrides: named._Named.toStr

Property Details

### datum Get the datum (Datum). Get method: datum(self) - Get the datum (Datum). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ellipsoid Get the datum's ellipsoid (Ellipsoid). Get method: ellipsoid(self) - Get the datum's ellipsoid (Ellipsoid). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatoradius Get the `ellipsoid`'s equatorial radius, semi-axis (`meter`). Get method: equatoradius(self) - Get the `ellipsoid`'s equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a Get the `ellipsoid`'s equatorial radius, semi-axis (`meter`). Get method: equatoradius(self) - Get the `ellipsoid`'s equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening Get the `ellipsoid`'s flattening (`scalar`). Get method: flattening(self) - Get the `ellipsoid`'s flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f Get the `ellipsoid`'s flattening (`scalar`). Get method: flattening(self) - Get the `ellipsoid`'s flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ispolar Is this projection polar (`bool`)? Get method: ispolar(self) - Is this projection polar (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat0 Get the latitude of the projection origin (`degrees`). This is the latitude of minimum azimuthal scale and equals the `lat` in the 1-parallel AlbersEqualArea and lies between `lat1` and `lat2` for the 2-parallel AlbersEqualArea2 and AlbersEqualArea4 projections. Get method: lat0(self) - Get the latitude of the projection origin (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat1 Get the latitude of the first parallel (`degrees`). Get method: lat1(self) - Get the latitude of the first parallel (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat2 Get the latitude of the second parallel (`degrees`). Get method: lat2(self) - Get the latitude of the second parallel (`degrees`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value. Note: The second and first parallel latitudes are the same instance for 1-parallel `AlbersEqualArea*` projections.

### majoradius DEPRECATED, use property `equatoradius`. Get method: majoradius(self) - DEPRECATED, use property `equatoradius`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### scale0 Get the central scale for the projection (`float`). This is the azimuthal scale on the latitude of origin of the projection, see `property lat0`. Get method: scale0(self) - Get the central scale for the projection (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.